@@ -147,7 +147,7 @@ static cleri_node_t * choice__parse_most_greedy(
     if (mg_node != NULL)
     {
         parent->len += mg_node->len;
-        if (cleri__children_add(parent->children, mg_node))
+        if (cleri__children_add(&parent->children, mg_node))
         {
              /* error occurred, reverse changes set mg_node to NULL */
             pr->is_valid = -1;
@@ -173,6 +173,26 @@ static cleri_node_t * choice__parse_first_match(
     cleri_node_t * rnode;
 
     olist = cl_obj->via.choice->olist;
+
+    if ((pr->flags & CLERI_FLAG_EXCLUDE_FM_CHOICE) && !cl_obj->gid)
+    {
+        while (olist != NULL)
+        {
+            node = cleri__parse_walk(
+                    pr,
+                    parent,
+                    olist->cl_obj,
+                    rule,
+                    CLERI__EXP_MODE_REQUIRED);
+            if (node != NULL)
+            {
+                return node;
+            }
+            olist = olist->next;
+        }
+       return NULL;
+    }
+
     node = cleri__node_new(cl_obj, parent->str + parent->len, 0);
     if (node == NULL)
     {
@@ -190,7 +210,7 @@ static cleri_node_t * choice__parse_first_match(
         if (rnode != NULL)
         {
             parent->len += node->len;
-            if (cleri__children_add(parent->children, node))
+            if (cleri__children_add(&parent->children, node))
             {
                  /* error occurred, reverse changes set mg_node to NULL */
                 pr->is_valid = -1;
