@@ -126,7 +126,7 @@ static cleri_node_t *  list__parse(
         return NULL;
     }
     parent->len += node->len;
-    if (cleri__children_add(parent->children, node))
+    if (cleri__children_add(&parent->children, node))
     {
          /* error occurred, reverse changes set mg_node to NULL */
         pr->is_valid = -1;
