@@ -35,9 +35,15 @@ static int test_regex(void)
     _assert_parse_str (
         grammar,
         "\"double quoted\"",
-        "error at position 0, expecting: single_quoted_string",
+        "error at line 0, position 0, "
+        "unexpected character `\"`, expecting: single_quoted_string",
+        translate);
+    _assert_parse_str2 (
+        grammar,
+        "\"double quoted\"",
+        "error at line 0, position 0, "
+        "unexpected character `\"`",
         translate);
-
     cleri_grammar_free(grammar);
 
     return test_end();
