@@ -19,7 +19,12 @@ static int test_token(void)
     _assert_parse_str (
         grammar,
         "",
-        "error at position 0, expecting: .",
+        "error at line 0, position 0, expecting: .",
+        NULL);
+    _assert_parse_str2 (
+        grammar,
+        "",
+        "error at line 0, position 0",
         NULL);
 
     cleri_grammar_free(grammar);
@@ -44,7 +49,12 @@ static int test_token_multi_char(void)
     _assert_parse_str (
         grammar,
         "",
-        "error at position 0, expecting: !=",
+        "error at line 0, position 0, expecting: !=",
+        NULL);
+    _assert_parse_str2 (
+        grammar,
+        "",
+        "error at line 0, position 0",
         NULL);
     cleri_grammar_free(grammar);
 
