@@ -24,9 +24,13 @@ static int test_tokens(void)
     _assert_parse_str (
         grammar,
         "",
-        "error at position 0, expecting: == != >= <= > <",
+        "error at line 0, position 0, expecting: == != >= <= > <",
+        NULL);
+    _assert_parse_str2 (
+        grammar,
+        "",
+        "error at line 0, position 0",
         NULL);
-
     cleri_grammar_free(grammar);
 
     return test_end();
